# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Transaction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address': 'str',
        'coins': 'Coins',
        'height': 'str',
        'tx_id': 'str'
    }

    attribute_map = {
        'address': 'address',
        'coins': 'coins',
        'height': 'height',
        'tx_id': 'txID'
    }

    def __init__(self, address=None, coins=None, height=None, tx_id=None):  # noqa: E501
        """Transaction - a model defined in Swagger"""  # noqa: E501
        self._address = None
        self._coins = None
        self._height = None
        self._tx_id = None
        self.discriminator = None
        self.address = address
        self.coins = coins
        if height is not None:
            self.height = height
        self.tx_id = tx_id

    @property
    def address(self):
        """Gets the address of this Transaction.  # noqa: E501

        Sender address  # noqa: E501

        :return: The address of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this Transaction.

        Sender address  # noqa: E501

        :param address: The address of this Transaction.  # noqa: E501
        :type: str
        """
        if address is None:
            raise ValueError("Invalid value for `address`, must not be `None`")  # noqa: E501

        self._address = address

    @property
    def coins(self):
        """Gets the coins of this Transaction.  # noqa: E501


        :return: The coins of this Transaction.  # noqa: E501
        :rtype: Coins
        """
        return self._coins

    @coins.setter
    def coins(self, coins):
        """Sets the coins of this Transaction.


        :param coins: The coins of this Transaction.  # noqa: E501
        :type: Coins
        """
        if coins is None:
            raise ValueError("Invalid value for `coins`, must not be `None`")  # noqa: E501

        self._coins = coins

    @property
    def height(self):
        """Gets the height of this Transaction.  # noqa: E501

        The thorchain height that the outbound transaction occurred.   # noqa: E501

        :return: The height of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this Transaction.

        The thorchain height that the outbound transaction occurred.   # noqa: E501

        :param height: The height of this Transaction.  # noqa: E501
        :type: str
        """

        self._height = height

    @property
    def tx_id(self):
        """Gets the tx_id of this Transaction.  # noqa: E501

        Transaction id hash. Some transactions (such as outbound transactions made in the native asset) may have a zero value.   # noqa: E501

        :return: The tx_id of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._tx_id

    @tx_id.setter
    def tx_id(self, tx_id):
        """Sets the tx_id of this Transaction.

        Transaction id hash. Some transactions (such as outbound transactions made in the native asset) may have a zero value.   # noqa: E501

        :param tx_id: The tx_id of this Transaction.  # noqa: E501
        :type: str
        """
        if tx_id is None:
            raise ValueError("Invalid value for `tx_id`, must not be `None`")  # noqa: E501

        self._tx_id = tx_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Transaction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Transaction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Action(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_date': 'str',
        'height': 'str',
        '_in': 'list[Transaction]',
        'metadata': 'Metadata',
        'out': 'list[Transaction]',
        'pools': 'list[str]',
        'status': 'str',
        'type': 'str'
    }

    attribute_map = {
        '_date': 'date',
        'height': 'height',
        '_in': 'in',
        'metadata': 'metadata',
        'out': 'out',
        'pools': 'pools',
        'status': 'status',
        'type': 'type'
    }

    def __init__(self, _date=None, height=None, _in=None, metadata=None, out=None, pools=None, status=None, type=None):  # noqa: E501
        """Action - a model defined in Swagger"""  # noqa: E501
        self.__date = None
        self._height = None
        self.__in = None
        self._metadata = None
        self._out = None
        self._pools = None
        self._status = None
        self._type = None
        self.discriminator = None
        self._date = _date
        self.height = height
        self._in = _in
        self.metadata = metadata
        self.out = out
        self.pools = pools
        self.status = status
        self.type = type

    @property
    def _date(self):
        """Gets the _date of this Action.  # noqa: E501

        Int64, nano timestamp of the block at which the action was registered  # noqa: E501

        :return: The _date of this Action.  # noqa: E501
        :rtype: str
        """
        return self.__date

    @_date.setter
    def _date(self, _date):
        """Sets the _date of this Action.

        Int64, nano timestamp of the block at which the action was registered  # noqa: E501

        :param _date: The _date of this Action.  # noqa: E501
        :type: str
        """
        if _date is None:
            raise ValueError("Invalid value for `_date`, must not be `None`")  # noqa: E501

        self.__date = _date

    @property
    def height(self):
        """Gets the height of this Action.  # noqa: E501

        Int64, height of the block at which the action was registered  # noqa: E501

        :return: The height of this Action.  # noqa: E501
        :rtype: str
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this Action.

        Int64, height of the block at which the action was registered  # noqa: E501

        :param height: The height of this Action.  # noqa: E501
        :type: str
        """
        if height is None:
            raise ValueError("Invalid value for `height`, must not be `None`")  # noqa: E501

        self._height = height

    @property
    def _in(self):
        """Gets the _in of this Action.  # noqa: E501

        Inbound transactions related to the action  # noqa: E501

        :return: The _in of this Action.  # noqa: E501
        :rtype: list[Transaction]
        """
        return self.__in

    @_in.setter
    def _in(self, _in):
        """Sets the _in of this Action.

        Inbound transactions related to the action  # noqa: E501

        :param _in: The _in of this Action.  # noqa: E501
        :type: list[Transaction]
        """
        if _in is None:
            raise ValueError("Invalid value for `_in`, must not be `None`")  # noqa: E501

        self.__in = _in

    @property
    def metadata(self):
        """Gets the metadata of this Action.  # noqa: E501


        :return: The metadata of this Action.  # noqa: E501
        :rtype: Metadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this Action.


        :param metadata: The metadata of this Action.  # noqa: E501
        :type: Metadata
        """
        if metadata is None:
            raise ValueError("Invalid value for `metadata`, must not be `None`")  # noqa: E501

        self._metadata = metadata

    @property
    def out(self):
        """Gets the out of this Action.  # noqa: E501

        Outbound transactions related to the action  # noqa: E501

        :return: The out of this Action.  # noqa: E501
        :rtype: list[Transaction]
        """
        return self._out

    @out.setter
    def out(self, out):
        """Sets the out of this Action.

        Outbound transactions related to the action  # noqa: E501

        :param out: The out of this Action.  # noqa: E501
        :type: list[Transaction]
        """
        if out is None:
            raise ValueError("Invalid value for `out`, must not be `None`")  # noqa: E501

        self._out = out

    @property
    def pools(self):
        """Gets the pools of this Action.  # noqa: E501

        Pools involved in the action  # noqa: E501

        :return: The pools of this Action.  # noqa: E501
        :rtype: list[str]
        """
        return self._pools

    @pools.setter
    def pools(self, pools):
        """Sets the pools of this Action.

        Pools involved in the action  # noqa: E501

        :param pools: The pools of this Action.  # noqa: E501
        :type: list[str]
        """
        if pools is None:
            raise ValueError("Invalid value for `pools`, must not be `None`")  # noqa: E501

        self._pools = pools

    @property
    def status(self):
        """Gets the status of this Action.  # noqa: E501

        Indicates if the action is completed or if related outbound transactions are still pending.   # noqa: E501

        :return: The status of this Action.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Action.

        Indicates if the action is completed or if related outbound transactions are still pending.   # noqa: E501

        :param status: The status of this Action.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["success", "pending"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def type(self):
        """Gets the type of this Action.  # noqa: E501

        Type of action  # noqa: E501

        :return: The type of this Action.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Action.

        Type of action  # noqa: E501

        :param type: The type of this Action.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["swap", "addLiquidity", "withdraw", "donate", "refund", "switch"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Action, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Action):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Node(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ed25519': 'str',
        'node_address': 'str',
        'secp256k1': 'str'
    }

    attribute_map = {
        'ed25519': 'ed25519',
        'node_address': 'nodeAddress',
        'secp256k1': 'secp256k1'
    }

    def __init__(self, ed25519=None, node_address=None, secp256k1=None):  # noqa: E501
        """Node - a model defined in Swagger"""  # noqa: E501
        self._ed25519 = None
        self._node_address = None
        self._secp256k1 = None
        self.discriminator = None
        self.ed25519 = ed25519
        self.node_address = node_address
        self.secp256k1 = secp256k1

    @property
    def ed25519(self):
        """Gets the ed25519 of this Node.  # noqa: E501

        ed25519 public key  # noqa: E501

        :return: The ed25519 of this Node.  # noqa: E501
        :rtype: str
        """
        return self._ed25519

    @ed25519.setter
    def ed25519(self, ed25519):
        """Sets the ed25519 of this Node.

        ed25519 public key  # noqa: E501

        :param ed25519: The ed25519 of this Node.  # noqa: E501
        :type: str
        """
        if ed25519 is None:
            raise ValueError("Invalid value for `ed25519`, must not be `None`")  # noqa: E501

        self._ed25519 = ed25519

    @property
    def node_address(self):
        """Gets the node_address of this Node.  # noqa: E501

        node thorchain address  # noqa: E501

        :return: The node_address of this Node.  # noqa: E501
        :rtype: str
        """
        return self._node_address

    @node_address.setter
    def node_address(self, node_address):
        """Sets the node_address of this Node.

        node thorchain address  # noqa: E501

        :param node_address: The node_address of this Node.  # noqa: E501
        :type: str
        """
        if node_address is None:
            raise ValueError("Invalid value for `node_address`, must not be `None`")  # noqa: E501

        self._node_address = node_address

    @property
    def secp256k1(self):
        """Gets the secp256k1 of this Node.  # noqa: E501

        secp256k1 public key  # noqa: E501

        :return: The secp256k1 of this Node.  # noqa: E501
        :rtype: str
        """
        return self._secp256k1

    @secp256k1.setter
    def secp256k1(self, secp256k1):
        """Sets the secp256k1 of this Node.

        secp256k1 public key  # noqa: E501

        :param secp256k1: The secp256k1 of this Node.  # noqa: E501
        :type: str
        """
        if secp256k1 is None:
            raise ValueError("Invalid value for `secp256k1`, must not be `None`")  # noqa: E501

        self._secp256k1 = secp256k1

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Node, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Node):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SwapMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'affiliate_address': 'str',
        'affiliate_fee': 'str',
        'is_streaming_swap': 'bool',
        'liquidity_fee': 'str',
        'memo': 'str',
        'network_fees': 'NetworkFees',
        'streaming_swap_meta': 'StreamingSwapMeta',
        'swap_slip': 'str',
        'swap_target': 'str'
    }

    attribute_map = {
        'affiliate_address': 'affiliateAddress',
        'affiliate_fee': 'affiliateFee',
        'is_streaming_swap': 'isStreamingSwap',
        'liquidity_fee': 'liquidityFee',
        'memo': 'memo',
        'network_fees': 'networkFees',
        'streaming_swap_meta': 'streamingSwapMeta',
        'swap_slip': 'swapSlip',
        'swap_target': 'swapTarget'
    }

    def __init__(self, affiliate_address=None, affiliate_fee=None, is_streaming_swap=None, liquidity_fee=None, memo=None, network_fees=None, streaming_swap_meta=None, swap_slip=None, swap_target=None):  # noqa: E501
        """SwapMetadata - a model defined in Swagger"""  # noqa: E501
        self._affiliate_address = None
        self._affiliate_fee = None
        self._is_streaming_swap = None
        self._liquidity_fee = None
        self._memo = None
        self._network_fees = None
        self._streaming_swap_meta = None
        self._swap_slip = None
        self._swap_target = None
        self.discriminator = None
        self.affiliate_address = affiliate_address
        self.affiliate_fee = affiliate_fee
        self.is_streaming_swap = is_streaming_swap
        self.liquidity_fee = liquidity_fee
        self.memo = memo
        self.network_fees = network_fees
        if streaming_swap_meta is not None:
            self.streaming_swap_meta = streaming_swap_meta
        self.swap_slip = swap_slip
        self.swap_target = swap_target

    @property
    def affiliate_address(self):
        """Gets the affiliate_address of this SwapMetadata.  # noqa: E501

        Affiliate fee address of the swap, empty if fee swap  # noqa: E501

        :return: The affiliate_address of this SwapMetadata.  # noqa: E501
        :rtype: str
        """
        return self._affiliate_address

    @affiliate_address.setter
    def affiliate_address(self, affiliate_address):
        """Sets the affiliate_address of this SwapMetadata.

        Affiliate fee address of the swap, empty if fee swap  # noqa: E501

        :param affiliate_address: The affiliate_address of this SwapMetadata.  # noqa: E501
        :type: str
        """
        if affiliate_address is None:
            raise ValueError("Invalid value for `affiliate_address`, must not be `None`")  # noqa: E501

        self._affiliate_address = affiliate_address

    @property
    def affiliate_fee(self):
        """Gets the affiliate_fee of this SwapMetadata.  # noqa: E501

        Int64 (Basis points, 0-1000, where 1000=10%)  # noqa: E501

        :return: The affiliate_fee of this SwapMetadata.  # noqa: E501
        :rtype: str
        """
        return self._affiliate_fee

    @affiliate_fee.setter
    def affiliate_fee(self, affiliate_fee):
        """Sets the affiliate_fee of this SwapMetadata.

        Int64 (Basis points, 0-1000, where 1000=10%)  # noqa: E501

        :param affiliate_fee: The affiliate_fee of this SwapMetadata.  # noqa: E501
        :type: str
        """
        if affiliate_fee is None:
            raise ValueError("Invalid value for `affiliate_fee`, must not be `None`")  # noqa: E501

        self._affiliate_fee = affiliate_fee

    @property
    def is_streaming_swap(self):
        """Gets the is_streaming_swap of this SwapMetadata.  # noqa: E501

        indicate whether this action was streaming  # noqa: E501

        :return: The is_streaming_swap of this SwapMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._is_streaming_swap

    @is_streaming_swap.setter
    def is_streaming_swap(self, is_streaming_swap):
        """Sets the is_streaming_swap of this SwapMetadata.

        indicate whether this action was streaming  # noqa: E501

        :param is_streaming_swap: The is_streaming_swap of this SwapMetadata.  # noqa: E501
        :type: bool
        """
        if is_streaming_swap is None:
            raise ValueError("Invalid value for `is_streaming_swap`, must not be `None`")  # noqa: E501

        self._is_streaming_swap = is_streaming_swap

    @property
    def liquidity_fee(self):
        """Gets the liquidity_fee of this SwapMetadata.  # noqa: E501

        Int64(e8), RUNE amount charged as swap liquidity fee  # noqa: E501

        :return: The liquidity_fee of this SwapMetadata.  # noqa: E501
        :rtype: str
        """
        return self._liquidity_fee

    @liquidity_fee.setter
    def liquidity_fee(self, liquidity_fee):
        """Sets the liquidity_fee of this SwapMetadata.

        Int64(e8), RUNE amount charged as swap liquidity fee  # noqa: E501

        :param liquidity_fee: The liquidity_fee of this SwapMetadata.  # noqa: E501
        :type: str
        """
        if liquidity_fee is None:
            raise ValueError("Invalid value for `liquidity_fee`, must not be `None`")  # noqa: E501

        self._liquidity_fee = liquidity_fee

    @property
    def memo(self):
        """Gets the memo of this SwapMetadata.  # noqa: E501

        Transaction memo of the swap action  # noqa: E501

        :return: The memo of this SwapMetadata.  # noqa: E501
        :rtype: str
        """
        return self._memo

    @memo.setter
    def memo(self, memo):
        """Sets the memo of this SwapMetadata.

        Transaction memo of the swap action  # noqa: E501

        :param memo: The memo of this SwapMetadata.  # noqa: E501
        :type: str
        """
        if memo is None:
            raise ValueError("Invalid value for `memo`, must not be `None`")  # noqa: E501

        self._memo = memo

    @property
    def network_fees(self):
        """Gets the network_fees of this SwapMetadata.  # noqa: E501


        :return: The network_fees of this SwapMetadata.  # noqa: E501
        :rtype: NetworkFees
        """
        return self._network_fees

    @network_fees.setter
    def network_fees(self, network_fees):
        """Sets the network_fees of this SwapMetadata.


        :param network_fees: The network_fees of this SwapMetadata.  # noqa: E501
        :type: NetworkFees
        """
        if network_fees is None:
            raise ValueError("Invalid value for `network_fees`, must not be `None`")  # noqa: E501

        self._network_fees = network_fees

    @property
    def streaming_swap_meta(self):
        """Gets the streaming_swap_meta of this SwapMetadata.  # noqa: E501


        :return: The streaming_swap_meta of this SwapMetadata.  # noqa: E501
        :rtype: StreamingSwapMeta
        """
        return self._streaming_swap_meta

    @streaming_swap_meta.setter
    def streaming_swap_meta(self, streaming_swap_meta):
        """Sets the streaming_swap_meta of this SwapMetadata.


        :param streaming_swap_meta: The streaming_swap_meta of this SwapMetadata.  # noqa: E501
        :type: StreamingSwapMeta
        """

        self._streaming_swap_meta = streaming_swap_meta

    @property
    def swap_slip(self):
        """Gets the swap_slip of this SwapMetadata.  # noqa: E501

        Int64 (Basis points, 0-10000, where 10000=100%), swap slip percentage  # noqa: E501

        :return: The swap_slip of this SwapMetadata.  # noqa: E501
        :rtype: str
        """
        return self._swap_slip

    @swap_slip.setter
    def swap_slip(self, swap_slip):
        """Sets the swap_slip of this SwapMetadata.

        Int64 (Basis points, 0-10000, where 10000=100%), swap slip percentage  # noqa: E501

        :param swap_slip: The swap_slip of this SwapMetadata.  # noqa: E501
        :type: str
        """
        if swap_slip is None:
            raise ValueError("Invalid value for `swap_slip`, must not be `None`")  # noqa: E501

        self._swap_slip = swap_slip

    @property
    def swap_target(self):
        """Gets the swap_target of this SwapMetadata.  # noqa: E501

        Int64(e8), minimum output amount specified for the swap  # noqa: E501

        :return: The swap_target of this SwapMetadata.  # noqa: E501
        :rtype: str
        """
        return self._swap_target

    @swap_target.setter
    def swap_target(self, swap_target):
        """Sets the swap_target of this SwapMetadata.

        Int64(e8), minimum output amount specified for the swap  # noqa: E501

        :param swap_target: The swap_target of this SwapMetadata.  # noqa: E501
        :type: str
        """
        if swap_target is None:
            raise ValueError("Invalid value for `swap_target`, must not be `None`")  # noqa: E501

        self._swap_target = swap_target

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SwapMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SwapMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class EarningsHistoryItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'avg_node_count': 'str',
        'block_rewards': 'str',
        'bonding_earnings': 'str',
        'earnings': 'str',
        'end_time': 'str',
        'liquidity_earnings': 'str',
        'liquidity_fees': 'str',
        'pools': 'list[EarningsHistoryItemPool]',
        'rune_price_usd': 'str',
        'start_time': 'str'
    }

    attribute_map = {
        'avg_node_count': 'avgNodeCount',
        'block_rewards': 'blockRewards',
        'bonding_earnings': 'bondingEarnings',
        'earnings': 'earnings',
        'end_time': 'endTime',
        'liquidity_earnings': 'liquidityEarnings',
        'liquidity_fees': 'liquidityFees',
        'pools': 'pools',
        'rune_price_usd': 'runePriceUSD',
        'start_time': 'startTime'
    }

    def __init__(self, avg_node_count=None, block_rewards=None, bonding_earnings=None, earnings=None, end_time=None, liquidity_earnings=None, liquidity_fees=None, pools=None, rune_price_usd=None, start_time=None):  # noqa: E501
        """EarningsHistoryItem - a model defined in Swagger"""  # noqa: E501
        self._avg_node_count = None
        self._block_rewards = None
        self._bonding_earnings = None
        self._earnings = None
        self._end_time = None
        self._liquidity_earnings = None
        self._liquidity_fees = None
        self._pools = None
        self._rune_price_usd = None
        self._start_time = None
        self.discriminator = None
        self.avg_node_count = avg_node_count
        self.block_rewards = block_rewards
        self.bonding_earnings = bonding_earnings
        self.earnings = earnings
        self.end_time = end_time
        self.liquidity_earnings = liquidity_earnings
        self.liquidity_fees = liquidity_fees
        self.pools = pools
        self.rune_price_usd = rune_price_usd
        self.start_time = start_time

    @property
    def avg_node_count(self):
        """Gets the avg_node_count of this EarningsHistoryItem.  # noqa: E501

        float64, Average amount of active nodes during the time interval  # noqa: E501

        :return: The avg_node_count of this EarningsHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._avg_node_count

    @avg_node_count.setter
    def avg_node_count(self, avg_node_count):
        """Sets the avg_node_count of this EarningsHistoryItem.

        float64, Average amount of active nodes during the time interval  # noqa: E501

        :param avg_node_count: The avg_node_count of this EarningsHistoryItem.  # noqa: E501
        :type: str
        """
        if avg_node_count is None:
            raise ValueError("Invalid value for `avg_node_count`, must not be `None`")  # noqa: E501

        self._avg_node_count = avg_node_count

    @property
    def block_rewards(self):
        """Gets the block_rewards of this EarningsHistoryItem.  # noqa: E501

        Int64(e8), Total block rewards emitted during the time interval  # noqa: E501

        :return: The block_rewards of this EarningsHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._block_rewards

    @block_rewards.setter
    def block_rewards(self, block_rewards):
        """Sets the block_rewards of this EarningsHistoryItem.

        Int64(e8), Total block rewards emitted during the time interval  # noqa: E501

        :param block_rewards: The block_rewards of this EarningsHistoryItem.  # noqa: E501
        :type: str
        """
        if block_rewards is None:
            raise ValueError("Invalid value for `block_rewards`, must not be `None`")  # noqa: E501

        self._block_rewards = block_rewards

    @property
    def bonding_earnings(self):
        """Gets the bonding_earnings of this EarningsHistoryItem.  # noqa: E501

        Int64(e8), Share of earnings sent to nodes during the time interval  # noqa: E501

        :return: The bonding_earnings of this EarningsHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._bonding_earnings

    @bonding_earnings.setter
    def bonding_earnings(self, bonding_earnings):
        """Sets the bonding_earnings of this EarningsHistoryItem.

        Int64(e8), Share of earnings sent to nodes during the time interval  # noqa: E501

        :param bonding_earnings: The bonding_earnings of this EarningsHistoryItem.  # noqa: E501
        :type: str
        """
        if bonding_earnings is None:
            raise ValueError("Invalid value for `bonding_earnings`, must not be `None`")  # noqa: E501

        self._bonding_earnings = bonding_earnings

    @property
    def earnings(self):
        """Gets the earnings of this EarningsHistoryItem.  # noqa: E501

        Int64(e8), System income generated during the time interval. It is the sum of liquidity fees and block rewards   # noqa: E501

        :return: The earnings of this EarningsHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._earnings

    @earnings.setter
    def earnings(self, earnings):
        """Sets the earnings of this EarningsHistoryItem.

        Int64(e8), System income generated during the time interval. It is the sum of liquidity fees and block rewards   # noqa: E501

        :param earnings: The earnings of this EarningsHistoryItem.  # noqa: E501
        :type: str
        """
        if earnings is None:
            raise ValueError("Invalid value for `earnings`, must not be `None`")  # noqa: E501

        self._earnings = earnings

    @property
    def end_time(self):
        """Gets the end_time of this EarningsHistoryItem.  # noqa: E501

        Int64, The end time of interval in unix timestamp  # noqa: E501

        :return: The end_time of this EarningsHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this EarningsHistoryItem.

        Int64, The end time of interval in unix timestamp  # noqa: E501

        :param end_time: The end_time of this EarningsHistoryItem.  # noqa: E501
        :type: str
        """
        if end_time is None:
            raise ValueError("Invalid value for `end_time`, must not be `None`")  # noqa: E501

        self._end_time = end_time

    @property
    def liquidity_earnings(self):
        """Gets the liquidity_earnings of this EarningsHistoryItem.  # noqa: E501

        Int64(e8), Share of earnings sent to pools during the time interval  # noqa: E501

        :return: The liquidity_earnings of this EarningsHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._liquidity_earnings

    @liquidity_earnings.setter
    def liquidity_earnings(self, liquidity_earnings):
        """Sets the liquidity_earnings of this EarningsHistoryItem.

        Int64(e8), Share of earnings sent to pools during the time interval  # noqa: E501

        :param liquidity_earnings: The liquidity_earnings of this EarningsHistoryItem.  # noqa: E501
        :type: str
        """
        if liquidity_earnings is None:
            raise ValueError("Invalid value for `liquidity_earnings`, must not be `None`")  # noqa: E501

        self._liquidity_earnings = liquidity_earnings

    @property
    def liquidity_fees(self):
        """Gets the liquidity_fees of this EarningsHistoryItem.  # noqa: E501

        Int64(e8), Total liquidity fees, converted to RUNE, collected during the time interval   # noqa: E501

        :return: The liquidity_fees of this EarningsHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._liquidity_fees

    @liquidity_fees.setter
    def liquidity_fees(self, liquidity_fees):
        """Sets the liquidity_fees of this EarningsHistoryItem.

        Int64(e8), Total liquidity fees, converted to RUNE, collected during the time interval   # noqa: E501

        :param liquidity_fees: The liquidity_fees of this EarningsHistoryItem.  # noqa: E501
        :type: str
        """
        if liquidity_fees is None:
            raise ValueError("Invalid value for `liquidity_fees`, must not be `None`")  # noqa: E501

        self._liquidity_fees = liquidity_fees

    @property
    def pools(self):
        """Gets the pools of this EarningsHistoryItem.  # noqa: E501

        Earnings data for each pool for the time interval  # noqa: E501

        :return: The pools of this EarningsHistoryItem.  # noqa: E501
        :rtype: list[EarningsHistoryItemPool]
        """
        return self._pools

    @pools.setter
    def pools(self, pools):
        """Sets the pools of this EarningsHistoryItem.

        Earnings data for each pool for the time interval  # noqa: E501

        :param pools: The pools of this EarningsHistoryItem.  # noqa: E501
        :type: list[EarningsHistoryItemPool]
        """
        if pools is None:
            raise ValueError("Invalid value for `pools`, must not be `None`")  # noqa: E501

        self._pools = pools

    @property
    def rune_price_usd(self):
        """Gets the rune_price_usd of this EarningsHistoryItem.  # noqa: E501

        Float, the price of Rune based on the deepest USD pool at the end of the interval.   # noqa: E501

        :return: The rune_price_usd of this EarningsHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._rune_price_usd

    @rune_price_usd.setter
    def rune_price_usd(self, rune_price_usd):
        """Sets the rune_price_usd of this EarningsHistoryItem.

        Float, the price of Rune based on the deepest USD pool at the end of the interval.   # noqa: E501

        :param rune_price_usd: The rune_price_usd of this EarningsHistoryItem.  # noqa: E501
        :type: str
        """
        if rune_price_usd is None:
            raise ValueError("Invalid value for `rune_price_usd`, must not be `None`")  # noqa: E501

        self._rune_price_usd = rune_price_usd

    @property
    def start_time(self):
        """Gets the start_time of this EarningsHistoryItem.  # noqa: E501

        Int64, The beginning time of interval in unix timestamp  # noqa: E501

        :return: The start_time of this EarningsHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this EarningsHistoryItem.

        Int64, The beginning time of interval in unix timestamp  # noqa: E501

        :param start_time: The start_time of this EarningsHistoryItem.  # noqa: E501
        :type: str
        """
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EarningsHistoryItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EarningsHistoryItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SaverPool(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset_added': 'str',
        'asset_address': 'str',
        'asset_deposit': 'str',
        'asset_redeem': 'str',
        'asset_withdrawn': 'str',
        'date_first_added': 'str',
        'date_last_added': 'str',
        'pool': 'str',
        'saver_units': 'str'
    }

    attribute_map = {
        'asset_added': 'assetAdded',
        'asset_address': 'assetAddress',
        'asset_deposit': 'assetDeposit',
        'asset_redeem': 'assetRedeem',
        'asset_withdrawn': 'assetWithdrawn',
        'date_first_added': 'dateFirstAdded',
        'date_last_added': 'dateLastAdded',
        'pool': 'pool',
        'saver_units': 'saverUnits'
    }

    def __init__(self, asset_added=None, asset_address=None, asset_deposit=None, asset_redeem=None, asset_withdrawn=None, date_first_added=None, date_last_added=None, pool=None, saver_units=None):  # noqa: E501
        """SaverPool - a model defined in Swagger"""  # noqa: E501
        self._asset_added = None
        self._asset_address = None
        self._asset_deposit = None
        self._asset_redeem = None
        self._asset_withdrawn = None
        self._date_first_added = None
        self._date_last_added = None
        self._pool = None
        self._saver_units = None
        self.discriminator = None
        self.asset_added = asset_added
        self.asset_address = asset_address
        self.asset_deposit = asset_deposit
        self.asset_redeem = asset_redeem
        self.asset_withdrawn = asset_withdrawn
        self.date_first_added = date_first_added
        self.date_last_added = date_last_added
        self.pool = pool
        self.saver_units = saver_units

    @property
    def asset_added(self):
        """Gets the asset_added of this SaverPool.  # noqa: E501

        Int64(e8), total asset added in the saver pool by member  # noqa: E501

        :return: The asset_added of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._asset_added

    @asset_added.setter
    def asset_added(self, asset_added):
        """Sets the asset_added of this SaverPool.

        Int64(e8), total asset added in the saver pool by member  # noqa: E501

        :param asset_added: The asset_added of this SaverPool.  # noqa: E501
        :type: str
        """
        if asset_added is None:
            raise ValueError("Invalid value for `asset_added`, must not be `None`")  # noqa: E501

        self._asset_added = asset_added

    @property
    def asset_address(self):
        """Gets the asset_address of this SaverPool.  # noqa: E501

        saver address used by the member  # noqa: E501

        :return: The asset_address of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._asset_address

    @asset_address.setter
    def asset_address(self, asset_address):
        """Sets the asset_address of this SaverPool.

        saver address used by the member  # noqa: E501

        :param asset_address: The asset_address of this SaverPool.  # noqa: E501
        :type: str
        """
        if asset_address is None:
            raise ValueError("Invalid value for `asset_address`, must not be `None`")  # noqa: E501

        self._asset_address = asset_address

    @property
    def asset_deposit(self):
        """Gets the asset_deposit of this SaverPool.  # noqa: E501

        Int64(e8), total asset that is currently deposited by the member  # noqa: E501

        :return: The asset_deposit of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._asset_deposit

    @asset_deposit.setter
    def asset_deposit(self, asset_deposit):
        """Sets the asset_deposit of this SaverPool.

        Int64(e8), total asset that is currently deposited by the member  # noqa: E501

        :param asset_deposit: The asset_deposit of this SaverPool.  # noqa: E501
        :type: str
        """
        if asset_deposit is None:
            raise ValueError("Invalid value for `asset_deposit`, must not be `None`")  # noqa: E501

        self._asset_deposit = asset_deposit

    @property
    def asset_redeem(self):
        """Gets the asset_redeem of this SaverPool.  # noqa: E501

        Int64(e8), total asset can be redeemed from the saver pool by member  # noqa: E501

        :return: The asset_redeem of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._asset_redeem

    @asset_redeem.setter
    def asset_redeem(self, asset_redeem):
        """Sets the asset_redeem of this SaverPool.

        Int64(e8), total asset can be redeemed from the saver pool by member  # noqa: E501

        :param asset_redeem: The asset_redeem of this SaverPool.  # noqa: E501
        :type: str
        """
        if asset_redeem is None:
            raise ValueError("Invalid value for `asset_redeem`, must not be `None`")  # noqa: E501

        self._asset_redeem = asset_redeem

    @property
    def asset_withdrawn(self):
        """Gets the asset_withdrawn of this SaverPool.  # noqa: E501

        Int64(e8), total asset withdrawn from the saver pool by member  # noqa: E501

        :return: The asset_withdrawn of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._asset_withdrawn

    @asset_withdrawn.setter
    def asset_withdrawn(self, asset_withdrawn):
        """Sets the asset_withdrawn of this SaverPool.

        Int64(e8), total asset withdrawn from the saver pool by member  # noqa: E501

        :param asset_withdrawn: The asset_withdrawn of this SaverPool.  # noqa: E501
        :type: str
        """
        if asset_withdrawn is None:
            raise ValueError("Invalid value for `asset_withdrawn`, must not be `None`")  # noqa: E501

        self._asset_withdrawn = asset_withdrawn

    @property
    def date_first_added(self):
        """Gets the date_first_added of this SaverPool.  # noqa: E501

        Int64, Unix timestamp for the first time member deposited into the saver pool  # noqa: E501

        :return: The date_first_added of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._date_first_added

    @date_first_added.setter
    def date_first_added(self, date_first_added):
        """Sets the date_first_added of this SaverPool.

        Int64, Unix timestamp for the first time member deposited into the saver pool  # noqa: E501

        :param date_first_added: The date_first_added of this SaverPool.  # noqa: E501
        :type: str
        """
        if date_first_added is None:
            raise ValueError("Invalid value for `date_first_added`, must not be `None`")  # noqa: E501

        self._date_first_added = date_first_added

    @property
    def date_last_added(self):
        """Gets the date_last_added of this SaverPool.  # noqa: E501

        Int64, Unix timestamp for the last time member deposited into the saver pool  # noqa: E501

        :return: The date_last_added of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._date_last_added

    @date_last_added.setter
    def date_last_added(self, date_last_added):
        """Sets the date_last_added of this SaverPool.

        Int64, Unix timestamp for the last time member deposited into the saver pool  # noqa: E501

        :param date_last_added: The date_last_added of this SaverPool.  # noqa: E501
        :type: str
        """
        if date_last_added is None:
            raise ValueError("Invalid value for `date_last_added`, must not be `None`")  # noqa: E501

        self._date_last_added = date_last_added

    @property
    def pool(self):
        """Gets the pool of this SaverPool.  # noqa: E501

        The Pool rest of the data are refering to (only those pools can show up which have a corresponding saver pool)  # noqa: E501

        :return: The pool of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._pool

    @pool.setter
    def pool(self, pool):
        """Sets the pool of this SaverPool.

        The Pool rest of the data are refering to (only those pools can show up which have a corresponding saver pool)  # noqa: E501

        :param pool: The pool of this SaverPool.  # noqa: E501
        :type: str
        """
        if pool is None:
            raise ValueError("Invalid value for `pool`, must not be `None`")  # noqa: E501

        self._pool = pool

    @property
    def saver_units(self):
        """Gets the saver_units of this SaverPool.  # noqa: E501

        Int64, saver liquidity units that belong the the member  # noqa: E501

        :return: The saver_units of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._saver_units

    @saver_units.setter
    def saver_units(self, saver_units):
        """Sets the saver_units of this SaverPool.

        Int64, saver liquidity units that belong the the member  # noqa: E501

        :param saver_units: The saver_units of this SaverPool.  # noqa: E501
        :type: str
        """
        if saver_units is None:
            raise ValueError("Invalid value for `saver_units`, must not be `None`")  # noqa: E501

        self._saver_units = saver_units

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SaverPool, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SaverPool):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RefundMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'affiliate_address': 'str',
        'affiliate_fee': 'str',
        'memo': 'str',
        'network_fees': 'NetworkFees',
        'reason': 'str'
    }

    attribute_map = {
        'affiliate_address': 'affiliateAddress',
        'affiliate_fee': 'affiliateFee',
        'memo': 'memo',
        'network_fees': 'networkFees',
        'reason': 'reason'
    }

    def __init__(self, affiliate_address=None, affiliate_fee=None, memo=None, network_fees=None, reason=None):  # noqa: E501
        """RefundMetadata - a model defined in Swagger"""  # noqa: E501
        self._affiliate_address = None
        self._affiliate_fee = None
        self._memo = None
        self._network_fees = None
        self._reason = None
        self.discriminator = None
        self.affiliate_address = affiliate_address
        self.affiliate_fee = affiliate_fee
        self.memo = memo
        self.network_fees = network_fees
        self.reason = reason

    @property
    def affiliate_address(self):
        """Gets the affiliate_address of this RefundMetadata.  # noqa: E501

        Affiliate fee address of the swap, empty if fee swap  # noqa: E501

        :return: The affiliate_address of this RefundMetadata.  # noqa: E501
        :rtype: str
        """
        return self._affiliate_address

    @affiliate_address.setter
    def affiliate_address(self, affiliate_address):
        """Sets the affiliate_address of this RefundMetadata.

        Affiliate fee address of the swap, empty if fee swap  # noqa: E501

        :param affiliate_address: The affiliate_address of this RefundMetadata.  # noqa: E501
        :type: str
        """
        if affiliate_address is None:
            raise ValueError("Invalid value for `affiliate_address`, must not be `None`")  # noqa: E501

        self._affiliate_address = affiliate_address

    @property
    def affiliate_fee(self):
        """Gets the affiliate_fee of this RefundMetadata.  # noqa: E501

        Int64 (Basis points, 0-1000, where 1000=10%)  # noqa: E501

        :return: The affiliate_fee of this RefundMetadata.  # noqa: E501
        :rtype: str
        """
        return self._affiliate_fee

    @affiliate_fee.setter
    def affiliate_fee(self, affiliate_fee):
        """Sets the affiliate_fee of this RefundMetadata.

        Int64 (Basis points, 0-1000, where 1000=10%)  # noqa: E501

        :param affiliate_fee: The affiliate_fee of this RefundMetadata.  # noqa: E501
        :type: str
        """
        if affiliate_fee is None:
            raise ValueError("Invalid value for `affiliate_fee`, must not be `None`")  # noqa: E501

        self._affiliate_fee = affiliate_fee

    @property
    def memo(self):
        """Gets the memo of this RefundMetadata.  # noqa: E501

        Transaction memo of the refund action  # noqa: E501

        :return: The memo of this RefundMetadata.  # noqa: E501
        :rtype: str
        """
        return self._memo

    @memo.setter
    def memo(self, memo):
        """Sets the memo of this RefundMetadata.

        Transaction memo of the refund action  # noqa: E501

        :param memo: The memo of this RefundMetadata.  # noqa: E501
        :type: str
        """
        if memo is None:
            raise ValueError("Invalid value for `memo`, must not be `None`")  # noqa: E501

        self._memo = memo

    @property
    def network_fees(self):
        """Gets the network_fees of this RefundMetadata.  # noqa: E501


        :return: The network_fees of this RefundMetadata.  # noqa: E501
        :rtype: NetworkFees
        """
        return self._network_fees

    @network_fees.setter
    def network_fees(self, network_fees):
        """Sets the network_fees of this RefundMetadata.


        :param network_fees: The network_fees of this RefundMetadata.  # noqa: E501
        :type: NetworkFees
        """
        if network_fees is None:
            raise ValueError("Invalid value for `network_fees`, must not be `None`")  # noqa: E501

        self._network_fees = network_fees

    @property
    def reason(self):
        """Gets the reason of this RefundMetadata.  # noqa: E501

        Reason for the refund  # noqa: E501

        :return: The reason of this RefundMetadata.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this RefundMetadata.

        Reason for the refund  # noqa: E501

        :param reason: The reason of this RefundMetadata.  # noqa: E501
        :type: str
        """
        if reason is None:
            raise ValueError("Invalid value for `reason`, must not be `None`")  # noqa: E501

        self._reason = reason

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RefundMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RefundMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Metadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'add_liquidity': 'AddLiquidityMetadata',
        'refund': 'RefundMetadata',
        'swap': 'SwapMetadata',
        'withdraw': 'WithdrawMetadata'
    }

    attribute_map = {
        'add_liquidity': 'addLiquidity',
        'refund': 'refund',
        'swap': 'swap',
        'withdraw': 'withdraw'
    }

    def __init__(self, add_liquidity=None, refund=None, swap=None, withdraw=None):  # noqa: E501
        """Metadata - a model defined in Swagger"""  # noqa: E501
        self._add_liquidity = None
        self._refund = None
        self._swap = None
        self._withdraw = None
        self.discriminator = None
        if add_liquidity is not None:
            self.add_liquidity = add_liquidity
        if refund is not None:
            self.refund = refund
        if swap is not None:
            self.swap = swap
        if withdraw is not None:
            self.withdraw = withdraw

    @property
    def add_liquidity(self):
        """Gets the add_liquidity of this Metadata.  # noqa: E501


        :return: The add_liquidity of this Metadata.  # noqa: E501
        :rtype: AddLiquidityMetadata
        """
        return self._add_liquidity

    @add_liquidity.setter
    def add_liquidity(self, add_liquidity):
        """Sets the add_liquidity of this Metadata.


        :param add_liquidity: The add_liquidity of this Metadata.  # noqa: E501
        :type: AddLiquidityMetadata
        """

        self._add_liquidity = add_liquidity

    @property
    def refund(self):
        """Gets the refund of this Metadata.  # noqa: E501


        :return: The refund of this Metadata.  # noqa: E501
        :rtype: RefundMetadata
        """
        return self._refund

    @refund.setter
    def refund(self, refund):
        """Sets the refund of this Metadata.


        :param refund: The refund of this Metadata.  # noqa: E501
        :type: RefundMetadata
        """

        self._refund = refund

    @property
    def swap(self):
        """Gets the swap of this Metadata.  # noqa: E501


        :return: The swap of this Metadata.  # noqa: E501
        :rtype: SwapMetadata
        """
        return self._swap

    @swap.setter
    def swap(self, swap):
        """Sets the swap of this Metadata.


        :param swap: The swap of this Metadata.  # noqa: E501
        :type: SwapMetadata
        """

        self._swap = swap

    @property
    def withdraw(self):
        """Gets the withdraw of this Metadata.  # noqa: E501


        :return: The withdraw of this Metadata.  # noqa: E501
        :rtype: WithdrawMetadata
        """
        return self._withdraw

    @withdraw.setter
    def withdraw(self, withdraw):
        """Sets the withdraw of this Metadata.


        :param withdraw: The withdraw of this Metadata.  # noqa: E501
        :type: WithdrawMetadata
        """

        self._withdraw = withdraw

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Metadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Metadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from xchainpy2_midgard.api_client import ApiClient


class SpecificationApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_docs(self, **kwargs):  # noqa: E501
        """Documentation  # noqa: E501

        Swagger/OpenAPI 3.0 specification generated documents.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_docs(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_docs_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_docs_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_docs_with_http_info(self, **kwargs):  # noqa: E501
        """Documentation  # noqa: E501

        Swagger/OpenAPI 3.0 specification generated documents.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_docs_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_docs" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/doc', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_swagger(self, **kwargs):  # noqa: E501
        """Swagger File  # noqa: E501

        Returns human and machine readable swagger/openapi specification  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_swagger(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_swagger_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_swagger_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_swagger_with_http_info(self, **kwargs):  # noqa: E501
        """Swagger File  # noqa: E501

        Returns human and machine readable swagger/openapi specification  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_swagger_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_swagger" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/swagger.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PoolDetail(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'annual_percentage_rate': 'str',
        'asset': 'str',
        'asset_depth': 'str',
        'asset_price': 'str',
        'asset_price_usd': 'str',
        'earnings': 'str',
        'earnings_annual_as_percent_of_depth': 'str',
        'liquidity_units': 'str',
        'lp_luvi': 'str',
        'native_decimal': 'str',
        'pool_apy': 'str',
        'rune_depth': 'str',
        'savers_apr': 'str',
        'savers_depth': 'str',
        'savers_units': 'str',
        'status': 'str',
        'synth_supply': 'str',
        'synth_units': 'str',
        'total_collateral': 'str',
        'total_debt_tor': 'str',
        'units': 'str',
        'volume24h': 'str'
    }

    attribute_map = {
        'annual_percentage_rate': 'annualPercentageRate',
        'asset': 'asset',
        'asset_depth': 'assetDepth',
        'asset_price': 'assetPrice',
        'asset_price_usd': 'assetPriceUSD',
        'earnings': 'earnings',
        'earnings_annual_as_percent_of_depth': 'earningsAnnualAsPercentOfDepth',
        'liquidity_units': 'liquidityUnits',
        'lp_luvi': 'lpLuvi',
        'native_decimal': 'nativeDecimal',
        'pool_apy': 'poolAPY',
        'rune_depth': 'runeDepth',
        'savers_apr': 'saversAPR',
        'savers_depth': 'saversDepth',
        'savers_units': 'saversUnits',
        'status': 'status',
        'synth_supply': 'synthSupply',
        'synth_units': 'synthUnits',
        'total_collateral': 'totalCollateral',
        'total_debt_tor': 'totalDebtTor',
        'units': 'units',
        'volume24h': 'volume24h'
    }

    def __init__(self, annual_percentage_rate=None, asset=None, asset_depth=None, asset_price=None, asset_price_usd=None, earnings=None, earnings_annual_as_percent_of_depth=None, liquidity_units=None, lp_luvi=None, native_decimal=None, pool_apy=None, rune_depth=None, savers_apr=None, savers_depth=None, savers_units=None, status=None, synth_supply=None, synth_units=None, total_collateral=None, total_debt_tor=None, units=None, volume24h=None):  # noqa: E501
        """PoolDetail - a model defined in Swagger"""  # noqa: E501
        self._annual_percentage_rate = None
        self._asset = None
        self._asset_depth = None
        self._asset_price = None
        self._asset_price_usd = None
        self._earnings = None
        self._earnings_annual_as_percent_of_depth = None
        self._liquidity_units = None
        self._lp_luvi = None
        self._native_decimal = None
        self._pool_apy = None
        self._rune_depth = None
        self._savers_apr = None
        self._savers_depth = None
        self._savers_units = None
        self._status = None
        self._synth_supply = None
        self._synth_units = None
        self._total_collateral = None
        self._total_debt_tor = None
        self._units = None
        self._volume24h = None
        self.discriminator = None
        self.annual_percentage_rate = annual_percentage_rate
        self.asset = asset
        self.asset_depth = asset_depth
        self.asset_price = asset_price
        self.asset_price_usd = asset_price_usd
        self.earnings = earnings
        self.earnings_annual_as_percent_of_depth = earnings_annual_as_percent_of_depth
        self.liquidity_units = liquidity_units
        self.lp_luvi = lp_luvi
        self.native_decimal = native_decimal
        self.pool_apy = pool_apy
        self.rune_depth = rune_depth
        self.savers_apr = savers_apr
        self.savers_depth = savers_depth
        self.savers_units = savers_units
        self.status = status
        self.synth_supply = synth_supply
        self.synth_units = synth_units
        self.total_collateral = total_collateral
        self.total_debt_tor = total_debt_tor
        self.units = units
        self.volume24h = volume24h

    @property
    def annual_percentage_rate(self):
        """Gets the annual_percentage_rate of this PoolDetail.  # noqa: E501

        Float, Annual Percentage Yield of earning to depth (earning/depth) estimated from a period (configurable by the period parameter, default is 14) E.g. 0.1 means 10% yearly return.   # noqa: E501

        :return: The annual_percentage_rate of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._annual_percentage_rate

    @annual_percentage_rate.setter
    def annual_percentage_rate(self, annual_percentage_rate):
        """Sets the annual_percentage_rate of this PoolDetail.

        Float, Annual Percentage Yield of earning to depth (earning/depth) estimated from a period (configurable by the period parameter, default is 14) E.g. 0.1 means 10% yearly return.   # noqa: E501

        :param annual_percentage_rate: The annual_percentage_rate of this PoolDetail.  # noqa: E501
        :type: str
        """
        if annual_percentage_rate is None:
            raise ValueError("Invalid value for `annual_percentage_rate`, must not be `None`")  # noqa: E501

        self._annual_percentage_rate = annual_percentage_rate

    @property
    def asset(self):
        """Gets the asset of this PoolDetail.  # noqa: E501


        :return: The asset of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._asset

    @asset.setter
    def asset(self, asset):
        """Sets the asset of this PoolDetail.


        :param asset: The asset of this PoolDetail.  # noqa: E501
        :type: str
        """
        if asset is None:
            raise ValueError("Invalid value for `asset`, must not be `None`")  # noqa: E501

        self._asset = asset

    @property
    def asset_depth(self):
        """Gets the asset_depth of this PoolDetail.  # noqa: E501

        Int64(e8), the amount of Asset in the pool.  # noqa: E501

        :return: The asset_depth of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._asset_depth

    @asset_depth.setter
    def asset_depth(self, asset_depth):
        """Sets the asset_depth of this PoolDetail.

        Int64(e8), the amount of Asset in the pool.  # noqa: E501

        :param asset_depth: The asset_depth of this PoolDetail.  # noqa: E501
        :type: str
        """
        if asset_depth is None:
            raise ValueError("Invalid value for `asset_depth`, must not be `None`")  # noqa: E501

        self._asset_depth = asset_depth

    @property
    def asset_price(self):
        """Gets the asset_price of this PoolDetail.  # noqa: E501

        Float, price of asset in rune. I.e. rune amount / asset amount.  # noqa: E501

        :return: The asset_price of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._asset_price

    @asset_price.setter
    def asset_price(self, asset_price):
        """Sets the asset_price of this PoolDetail.

        Float, price of asset in rune. I.e. rune amount / asset amount.  # noqa: E501

        :param asset_price: The asset_price of this PoolDetail.  # noqa: E501
        :type: str
        """
        if asset_price is None:
            raise ValueError("Invalid value for `asset_price`, must not be `None`")  # noqa: E501

        self._asset_price = asset_price

    @property
    def asset_price_usd(self):
        """Gets the asset_price_usd of this PoolDetail.  # noqa: E501

        Float, the price of asset in USD (based on the deepest USD pool).  # noqa: E501

        :return: The asset_price_usd of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._asset_price_usd

    @asset_price_usd.setter
    def asset_price_usd(self, asset_price_usd):
        """Sets the asset_price_usd of this PoolDetail.

        Float, the price of asset in USD (based on the deepest USD pool).  # noqa: E501

        :param asset_price_usd: The asset_price_usd of this PoolDetail.  # noqa: E501
        :type: str
        """
        if asset_price_usd is None:
            raise ValueError("Invalid value for `asset_price_usd`, must not be `None`")  # noqa: E501

        self._asset_price_usd = asset_price_usd

    @property
    def earnings(self):
        """Gets the earnings of this PoolDetail.  # noqa: E501

        Int64(e8), The earning that has been recorded from the pool asset's Liquidity Fees and Rewards in RUNE. The earnings shown are from the period parameter default being 14 days  (configurable by the period parameter).   # noqa: E501

        :return: The earnings of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._earnings

    @earnings.setter
    def earnings(self, earnings):
        """Sets the earnings of this PoolDetail.

        Int64(e8), The earning that has been recorded from the pool asset's Liquidity Fees and Rewards in RUNE. The earnings shown are from the period parameter default being 14 days  (configurable by the period parameter).   # noqa: E501

        :param earnings: The earnings of this PoolDetail.  # noqa: E501
        :type: str
        """
        if earnings is None:
            raise ValueError("Invalid value for `earnings`, must not be `None`")  # noqa: E501

        self._earnings = earnings

    @property
    def earnings_annual_as_percent_of_depth(self):
        """Gets the earnings_annual_as_percent_of_depth of this PoolDetail.  # noqa: E501

        Float, The estimation of earnings during the time interval expanded through a year  compared to the current pool depth. E.g. 0.1 means the pool based on this interval earnings can earn 10% of its pool during a year.   # noqa: E501

        :return: The earnings_annual_as_percent_of_depth of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._earnings_annual_as_percent_of_depth

    @earnings_annual_as_percent_of_depth.setter
    def earnings_annual_as_percent_of_depth(self, earnings_annual_as_percent_of_depth):
        """Sets the earnings_annual_as_percent_of_depth of this PoolDetail.

        Float, The estimation of earnings during the time interval expanded through a year  compared to the current pool depth. E.g. 0.1 means the pool based on this interval earnings can earn 10% of its pool during a year.   # noqa: E501

        :param earnings_annual_as_percent_of_depth: The earnings_annual_as_percent_of_depth of this PoolDetail.  # noqa: E501
        :type: str
        """
        if earnings_annual_as_percent_of_depth is None:
            raise ValueError("Invalid value for `earnings_annual_as_percent_of_depth`, must not be `None`")  # noqa: E501

        self._earnings_annual_as_percent_of_depth = earnings_annual_as_percent_of_depth

    @property
    def liquidity_units(self):
        """Gets the liquidity_units of this PoolDetail.  # noqa: E501

        Int64, Liquidity Units in the pool.  # noqa: E501

        :return: The liquidity_units of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._liquidity_units

    @liquidity_units.setter
    def liquidity_units(self, liquidity_units):
        """Sets the liquidity_units of this PoolDetail.

        Int64, Liquidity Units in the pool.  # noqa: E501

        :param liquidity_units: The liquidity_units of this PoolDetail.  # noqa: E501
        :type: str
        """
        if liquidity_units is None:
            raise ValueError("Invalid value for `liquidity_units`, must not be `None`")  # noqa: E501

        self._liquidity_units = liquidity_units

    @property
    def lp_luvi(self):
        """Gets the lp_luvi of this PoolDetail.  # noqa: E501

        Float, Annual yield estimated (compounding) from a period (default being 14d) configurable by the period parameter. Calculated from Liquidity Unit Value Index (LUVI). Due to Impermanent Loss and Synths Leverage this might be negative.   # noqa: E501

        :return: The lp_luvi of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._lp_luvi

    @lp_luvi.setter
    def lp_luvi(self, lp_luvi):
        """Sets the lp_luvi of this PoolDetail.

        Float, Annual yield estimated (compounding) from a period (default being 14d) configurable by the period parameter. Calculated from Liquidity Unit Value Index (LUVI). Due to Impermanent Loss and Synths Leverage this might be negative.   # noqa: E501

        :param lp_luvi: The lp_luvi of this PoolDetail.  # noqa: E501
        :type: str
        """
        if lp_luvi is None:
            raise ValueError("Invalid value for `lp_luvi`, must not be `None`")  # noqa: E501

        self._lp_luvi = lp_luvi

    @property
    def native_decimal(self):
        """Gets the native_decimal of this PoolDetail.  # noqa: E501

        Int64, The native decimal number of the pool asset. (If the value is \"-1\", it means midgard doesn't know the pool native decimal)  # noqa: E501

        :return: The native_decimal of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._native_decimal

    @native_decimal.setter
    def native_decimal(self, native_decimal):
        """Sets the native_decimal of this PoolDetail.

        Int64, The native decimal number of the pool asset. (If the value is \"-1\", it means midgard doesn't know the pool native decimal)  # noqa: E501

        :param native_decimal: The native_decimal of this PoolDetail.  # noqa: E501
        :type: str
        """
        if native_decimal is None:
            raise ValueError("Invalid value for `native_decimal`, must not be `None`")  # noqa: E501

        self._native_decimal = native_decimal

    @property
    def pool_apy(self):
        """Gets the pool_apy of this PoolDetail.  # noqa: E501

        Float, Annual Percentage Yield of earning to depth (earning/depth) estimated from a period (configurable by the period parameter, default is 14) E.g. 0.1 means 10% yearly return.   # noqa: E501

        :return: The pool_apy of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._pool_apy

    @pool_apy.setter
    def pool_apy(self, pool_apy):
        """Sets the pool_apy of this PoolDetail.

        Float, Annual Percentage Yield of earning to depth (earning/depth) estimated from a period (configurable by the period parameter, default is 14) E.g. 0.1 means 10% yearly return.   # noqa: E501

        :param pool_apy: The pool_apy of this PoolDetail.  # noqa: E501
        :type: str
        """
        if pool_apy is None:
            raise ValueError("Invalid value for `pool_apy`, must not be `None`")  # noqa: E501

        self._pool_apy = pool_apy

    @property
    def rune_depth(self):
        """Gets the rune_depth of this PoolDetail.  # noqa: E501

        Int64(e8), the amount of Rune in the pool.  # noqa: E501

        :return: The rune_depth of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._rune_depth

    @rune_depth.setter
    def rune_depth(self, rune_depth):
        """Sets the rune_depth of this PoolDetail.

        Int64(e8), the amount of Rune in the pool.  # noqa: E501

        :param rune_depth: The rune_depth of this PoolDetail.  # noqa: E501
        :type: str
        """
        if rune_depth is None:
            raise ValueError("Invalid value for `rune_depth`, must not be `None`")  # noqa: E501

        self._rune_depth = rune_depth

    @property
    def savers_apr(self):
        """Gets the savers_apr of this PoolDetail.  # noqa: E501

        Float, Annual Return estimated linearly (not compounded) for savers from a period of typically the last 30 or 100 days (configurable by the period parameter, default is 14). E.g. 0.1 means 10% yearly return. If the savers period has not yet been reached, It will show zero instead.   # noqa: E501

        :return: The savers_apr of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._savers_apr

    @savers_apr.setter
    def savers_apr(self, savers_apr):
        """Sets the savers_apr of this PoolDetail.

        Float, Annual Return estimated linearly (not compounded) for savers from a period of typically the last 30 or 100 days (configurable by the period parameter, default is 14). E.g. 0.1 means 10% yearly return. If the savers period has not yet been reached, It will show zero instead.   # noqa: E501

        :param savers_apr: The savers_apr of this PoolDetail.  # noqa: E501
        :type: str
        """
        if savers_apr is None:
            raise ValueError("Invalid value for `savers_apr`, must not be `None`")  # noqa: E501

        self._savers_apr = savers_apr

    @property
    def savers_depth(self):
        """Gets the savers_depth of this PoolDetail.  # noqa: E501

        Int64, Total synth locked in saver vault.  # noqa: E501

        :return: The savers_depth of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._savers_depth

    @savers_depth.setter
    def savers_depth(self, savers_depth):
        """Sets the savers_depth of this PoolDetail.

        Int64, Total synth locked in saver vault.  # noqa: E501

        :param savers_depth: The savers_depth of this PoolDetail.  # noqa: E501
        :type: str
        """
        if savers_depth is None:
            raise ValueError("Invalid value for `savers_depth`, must not be `None`")  # noqa: E501

        self._savers_depth = savers_depth

    @property
    def savers_units(self):
        """Gets the savers_units of this PoolDetail.  # noqa: E501

        Int64, Units tracking savers vault ownership.  # noqa: E501

        :return: The savers_units of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._savers_units

    @savers_units.setter
    def savers_units(self, savers_units):
        """Sets the savers_units of this PoolDetail.

        Int64, Units tracking savers vault ownership.  # noqa: E501

        :param savers_units: The savers_units of this PoolDetail.  # noqa: E501
        :type: str
        """
        if savers_units is None:
            raise ValueError("Invalid value for `savers_units`, must not be `None`")  # noqa: E501

        self._savers_units = savers_units

    @property
    def status(self):
        """Gets the status of this PoolDetail.  # noqa: E501

        The state of the pool, e.g. Available, Staged.  # noqa: E501

        :return: The status of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PoolDetail.

        The state of the pool, e.g. Available, Staged.  # noqa: E501

        :param status: The status of this PoolDetail.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def synth_supply(self):
        """Gets the synth_supply of this PoolDetail.  # noqa: E501

        Int64, Synth supply in the pool.  # noqa: E501

        :return: The synth_supply of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._synth_supply

    @synth_supply.setter
    def synth_supply(self, synth_supply):
        """Sets the synth_supply of this PoolDetail.

        Int64, Synth supply in the pool.  # noqa: E501

        :param synth_supply: The synth_supply of this PoolDetail.  # noqa: E501
        :type: str
        """
        if synth_supply is None:
            raise ValueError("Invalid value for `synth_supply`, must not be `None`")  # noqa: E501

        self._synth_supply = synth_supply

    @property
    def synth_units(self):
        """Gets the synth_units of this PoolDetail.  # noqa: E501

        Int64, Synth Units in the pool.  # noqa: E501

        :return: The synth_units of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._synth_units

    @synth_units.setter
    def synth_units(self, synth_units):
        """Sets the synth_units of this PoolDetail.

        Int64, Synth Units in the pool.  # noqa: E501

        :param synth_units: The synth_units of this PoolDetail.  # noqa: E501
        :type: str
        """
        if synth_units is None:
            raise ValueError("Invalid value for `synth_units`, must not be `None`")  # noqa: E501

        self._synth_units = synth_units

    @property
    def total_collateral(self):
        """Gets the total_collateral of this PoolDetail.  # noqa: E501

        Int64, Total collateral of the pool created by the borrowers.  # noqa: E501

        :return: The total_collateral of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._total_collateral

    @total_collateral.setter
    def total_collateral(self, total_collateral):
        """Sets the total_collateral of this PoolDetail.

        Int64, Total collateral of the pool created by the borrowers.  # noqa: E501

        :param total_collateral: The total_collateral of this PoolDetail.  # noqa: E501
        :type: str
        """
        if total_collateral is None:
            raise ValueError("Invalid value for `total_collateral`, must not be `None`")  # noqa: E501

        self._total_collateral = total_collateral

    @property
    def total_debt_tor(self):
        """Gets the total_debt_tor of this PoolDetail.  # noqa: E501

        Int64, Total debt of the pool by the borrowers.  # noqa: E501

        :return: The total_debt_tor of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._total_debt_tor

    @total_debt_tor.setter
    def total_debt_tor(self, total_debt_tor):
        """Sets the total_debt_tor of this PoolDetail.

        Int64, Total debt of the pool by the borrowers.  # noqa: E501

        :param total_debt_tor: The total_debt_tor of this PoolDetail.  # noqa: E501
        :type: str
        """
        if total_debt_tor is None:
            raise ValueError("Invalid value for `total_debt_tor`, must not be `None`")  # noqa: E501

        self._total_debt_tor = total_debt_tor

    @property
    def units(self):
        """Gets the units of this PoolDetail.  # noqa: E501

        Int64, Total Units (synthUnits + liquidityUnits) in the pool.  # noqa: E501

        :return: The units of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this PoolDetail.

        Int64, Total Units (synthUnits + liquidityUnits) in the pool.  # noqa: E501

        :param units: The units of this PoolDetail.  # noqa: E501
        :type: str
        """
        if units is None:
            raise ValueError("Invalid value for `units`, must not be `None`")  # noqa: E501

        self._units = units

    @property
    def volume24h(self):
        """Gets the volume24h of this PoolDetail.  # noqa: E501

        Int64(e8), the total volume of swaps in the last 24h to and from Rune denoted in Rune. It includes synth mint or burn.   # noqa: E501

        :return: The volume24h of this PoolDetail.  # noqa: E501
        :rtype: str
        """
        return self._volume24h

    @volume24h.setter
    def volume24h(self, volume24h):
        """Sets the volume24h of this PoolDetail.

        Int64(e8), the total volume of swaps in the last 24h to and from Rune denoted in Rune. It includes synth mint or burn.   # noqa: E501

        :param volume24h: The volume24h of this PoolDetail.  # noqa: E501
        :type: str
        """
        if volume24h is None:
            raise ValueError("Invalid value for `volume24h`, must not be `None`")  # noqa: E501

        self._volume24h = volume24h

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PoolDetail, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PoolDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from xchainpy2_midgard.api.specification_api import SpecificationApi
from xchainpy2_midgard.api.default_api import DefaultApi



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StatsData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'add_liquidity_count': 'str',
        'add_liquidity_volume': 'str',
        'daily_active_users': 'str',
        'monthly_active_users': 'str',
        'rune_depth': 'str',
        'rune_price_usd': 'str',
        'swap_count': 'str',
        'swap_count24h': 'str',
        'swap_count30d': 'str',
        'swap_volume': 'str',
        'switched_rune': 'str',
        'synth_burn_count': 'str',
        'synth_mint_count': 'str',
        'to_asset_count': 'str',
        'to_rune_count': 'str',
        'unique_swapper_count': 'str',
        'withdraw_count': 'str',
        'withdraw_volume': 'str'
    }

    attribute_map = {
        'add_liquidity_count': 'addLiquidityCount',
        'add_liquidity_volume': 'addLiquidityVolume',
        'daily_active_users': 'dailyActiveUsers',
        'monthly_active_users': 'monthlyActiveUsers',
        'rune_depth': 'runeDepth',
        'rune_price_usd': 'runePriceUSD',
        'swap_count': 'swapCount',
        'swap_count24h': 'swapCount24h',
        'swap_count30d': 'swapCount30d',
        'swap_volume': 'swapVolume',
        'switched_rune': 'switchedRune',
        'synth_burn_count': 'synthBurnCount',
        'synth_mint_count': 'synthMintCount',
        'to_asset_count': 'toAssetCount',
        'to_rune_count': 'toRuneCount',
        'unique_swapper_count': 'uniqueSwapperCount',
        'withdraw_count': 'withdrawCount',
        'withdraw_volume': 'withdrawVolume'
    }

    def __init__(self, add_liquidity_count=None, add_liquidity_volume=None, daily_active_users=None, monthly_active_users=None, rune_depth=None, rune_price_usd=None, swap_count=None, swap_count24h=None, swap_count30d=None, swap_volume=None, switched_rune=None, synth_burn_count=None, synth_mint_count=None, to_asset_count=None, to_rune_count=None, unique_swapper_count=None, withdraw_count=None, withdraw_volume=None):  # noqa: E501
        """StatsData - a model defined in Swagger"""  # noqa: E501
        self._add_liquidity_count = None
        self._add_liquidity_volume = None
        self._daily_active_users = None
        self._monthly_active_users = None
        self._rune_depth = None
        self._rune_price_usd = None
        self._swap_count = None
        self._swap_count24h = None
        self._swap_count30d = None
        self._swap_volume = None
        self._switched_rune = None
        self._synth_burn_count = None
        self._synth_mint_count = None
        self._to_asset_count = None
        self._to_rune_count = None
        self._unique_swapper_count = None
        self._withdraw_count = None
        self._withdraw_volume = None
        self.discriminator = None
        self.add_liquidity_count = add_liquidity_count
        self.add_liquidity_volume = add_liquidity_volume
        self.daily_active_users = daily_active_users
        self.monthly_active_users = monthly_active_users
        self.rune_depth = rune_depth
        self.rune_price_usd = rune_price_usd
        self.swap_count = swap_count
        self.swap_count24h = swap_count24h
        self.swap_count30d = swap_count30d
        self.swap_volume = swap_volume
        self.switched_rune = switched_rune
        self.synth_burn_count = synth_burn_count
        self.synth_mint_count = synth_mint_count
        self.to_asset_count = to_asset_count
        self.to_rune_count = to_rune_count
        self.unique_swapper_count = unique_swapper_count
        self.withdraw_count = withdraw_count
        self.withdraw_volume = withdraw_volume

    @property
    def add_liquidity_count(self):
        """Gets the add_liquidity_count of this StatsData.  # noqa: E501

        Int64, number of deposits since beginning.  # noqa: E501

        :return: The add_liquidity_count of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._add_liquidity_count

    @add_liquidity_count.setter
    def add_liquidity_count(self, add_liquidity_count):
        """Sets the add_liquidity_count of this StatsData.

        Int64, number of deposits since beginning.  # noqa: E501

        :param add_liquidity_count: The add_liquidity_count of this StatsData.  # noqa: E501
        :type: str
        """
        if add_liquidity_count is None:
            raise ValueError("Invalid value for `add_liquidity_count`, must not be `None`")  # noqa: E501

        self._add_liquidity_count = add_liquidity_count

    @property
    def add_liquidity_volume(self):
        """Gets the add_liquidity_volume of this StatsData.  # noqa: E501

        Int64(e8), total of deposits since beginning.   # noqa: E501

        :return: The add_liquidity_volume of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._add_liquidity_volume

    @add_liquidity_volume.setter
    def add_liquidity_volume(self, add_liquidity_volume):
        """Sets the add_liquidity_volume of this StatsData.

        Int64(e8), total of deposits since beginning.   # noqa: E501

        :param add_liquidity_volume: The add_liquidity_volume of this StatsData.  # noqa: E501
        :type: str
        """
        if add_liquidity_volume is None:
            raise ValueError("Invalid value for `add_liquidity_volume`, must not be `None`")  # noqa: E501

        self._add_liquidity_volume = add_liquidity_volume

    @property
    def daily_active_users(self):
        """Gets the daily_active_users of this StatsData.  # noqa: E501

        Deprecated, it's always 0.  # noqa: E501

        :return: The daily_active_users of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._daily_active_users

    @daily_active_users.setter
    def daily_active_users(self, daily_active_users):
        """Sets the daily_active_users of this StatsData.

        Deprecated, it's always 0.  # noqa: E501

        :param daily_active_users: The daily_active_users of this StatsData.  # noqa: E501
        :type: str
        """
        if daily_active_users is None:
            raise ValueError("Invalid value for `daily_active_users`, must not be `None`")  # noqa: E501

        self._daily_active_users = daily_active_users

    @property
    def monthly_active_users(self):
        """Gets the monthly_active_users of this StatsData.  # noqa: E501

        Deprecated, it's always 0.  # noqa: E501

        :return: The monthly_active_users of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._monthly_active_users

    @monthly_active_users.setter
    def monthly_active_users(self, monthly_active_users):
        """Sets the monthly_active_users of this StatsData.

        Deprecated, it's always 0.  # noqa: E501

        :param monthly_active_users: The monthly_active_users of this StatsData.  # noqa: E501
        :type: str
        """
        if monthly_active_users is None:
            raise ValueError("Invalid value for `monthly_active_users`, must not be `None`")  # noqa: E501

        self._monthly_active_users = monthly_active_users

    @property
    def rune_depth(self):
        """Gets the rune_depth of this StatsData.  # noqa: E501

        Int64(e8), current total Rune in the pools.  # noqa: E501

        :return: The rune_depth of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._rune_depth

    @rune_depth.setter
    def rune_depth(self, rune_depth):
        """Sets the rune_depth of this StatsData.

        Int64(e8), current total Rune in the pools.  # noqa: E501

        :param rune_depth: The rune_depth of this StatsData.  # noqa: E501
        :type: str
        """
        if rune_depth is None:
            raise ValueError("Invalid value for `rune_depth`, must not be `None`")  # noqa: E501

        self._rune_depth = rune_depth

    @property
    def rune_price_usd(self):
        """Gets the rune_price_usd of this StatsData.  # noqa: E501

        Float, the price of Rune based on the deepest USD pool.  # noqa: E501

        :return: The rune_price_usd of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._rune_price_usd

    @rune_price_usd.setter
    def rune_price_usd(self, rune_price_usd):
        """Sets the rune_price_usd of this StatsData.

        Float, the price of Rune based on the deepest USD pool.  # noqa: E501

        :param rune_price_usd: The rune_price_usd of this StatsData.  # noqa: E501
        :type: str
        """
        if rune_price_usd is None:
            raise ValueError("Invalid value for `rune_price_usd`, must not be `None`")  # noqa: E501

        self._rune_price_usd = rune_price_usd

    @property
    def swap_count(self):
        """Gets the swap_count of this StatsData.  # noqa: E501

        Int64, number of swaps (including synths) since beginning.  # noqa: E501

        :return: The swap_count of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._swap_count

    @swap_count.setter
    def swap_count(self, swap_count):
        """Sets the swap_count of this StatsData.

        Int64, number of swaps (including synths) since beginning.  # noqa: E501

        :param swap_count: The swap_count of this StatsData.  # noqa: E501
        :type: str
        """
        if swap_count is None:
            raise ValueError("Invalid value for `swap_count`, must not be `None`")  # noqa: E501

        self._swap_count = swap_count

    @property
    def swap_count24h(self):
        """Gets the swap_count24h of this StatsData.  # noqa: E501

        Int64(e8), number of swaps (including synths) in the last 24h.  # noqa: E501

        :return: The swap_count24h of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._swap_count24h

    @swap_count24h.setter
    def swap_count24h(self, swap_count24h):
        """Sets the swap_count24h of this StatsData.

        Int64(e8), number of swaps (including synths) in the last 24h.  # noqa: E501

        :param swap_count24h: The swap_count24h of this StatsData.  # noqa: E501
        :type: str
        """
        if swap_count24h is None:
            raise ValueError("Invalid value for `swap_count24h`, must not be `None`")  # noqa: E501

        self._swap_count24h = swap_count24h

    @property
    def swap_count30d(self):
        """Gets the swap_count30d of this StatsData.  # noqa: E501

        Int64, number of swaps (including synths) in the last 30d.  # noqa: E501

        :return: The swap_count30d of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._swap_count30d

    @swap_count30d.setter
    def swap_count30d(self, swap_count30d):
        """Sets the swap_count30d of this StatsData.

        Int64, number of swaps (including synths) in the last 30d.  # noqa: E501

        :param swap_count30d: The swap_count30d of this StatsData.  # noqa: E501
        :type: str
        """
        if swap_count30d is None:
            raise ValueError("Invalid value for `swap_count30d`, must not be `None`")  # noqa: E501

        self._swap_count30d = swap_count30d

    @property
    def swap_volume(self):
        """Gets the swap_volume of this StatsData.  # noqa: E501

        Int64(e8), total volume of swaps (including synths) denoted in Rune since beginning.   # noqa: E501

        :return: The swap_volume of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._swap_volume

    @swap_volume.setter
    def swap_volume(self, swap_volume):
        """Sets the swap_volume of this StatsData.

        Int64(e8), total volume of swaps (including synths) denoted in Rune since beginning.   # noqa: E501

        :param swap_volume: The swap_volume of this StatsData.  # noqa: E501
        :type: str
        """
        if swap_volume is None:
            raise ValueError("Invalid value for `swap_volume`, must not be `None`")  # noqa: E501

        self._swap_volume = swap_volume

    @property
    def switched_rune(self):
        """Gets the switched_rune of this StatsData.  # noqa: E501

        Int64(e8), amount of native rune switched from erc20 or bep2 rune.  # noqa: E501

        :return: The switched_rune of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._switched_rune

    @switched_rune.setter
    def switched_rune(self, switched_rune):
        """Sets the switched_rune of this StatsData.

        Int64(e8), amount of native rune switched from erc20 or bep2 rune.  # noqa: E501

        :param switched_rune: The switched_rune of this StatsData.  # noqa: E501
        :type: str
        """
        if switched_rune is None:
            raise ValueError("Invalid value for `switched_rune`, must not be `None`")  # noqa: E501

        self._switched_rune = switched_rune

    @property
    def synth_burn_count(self):
        """Gets the synth_burn_count of this StatsData.  # noqa: E501

        Int64, number of swaps from Synth to Rune since beginning.  # noqa: E501

        :return: The synth_burn_count of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._synth_burn_count

    @synth_burn_count.setter
    def synth_burn_count(self, synth_burn_count):
        """Sets the synth_burn_count of this StatsData.

        Int64, number of swaps from Synth to Rune since beginning.  # noqa: E501

        :param synth_burn_count: The synth_burn_count of this StatsData.  # noqa: E501
        :type: str
        """
        if synth_burn_count is None:
            raise ValueError("Invalid value for `synth_burn_count`, must not be `None`")  # noqa: E501

        self._synth_burn_count = synth_burn_count

    @property
    def synth_mint_count(self):
        """Gets the synth_mint_count of this StatsData.  # noqa: E501

        Int64, number of swaps from Rune to Synth since beginning.  # noqa: E501

        :return: The synth_mint_count of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._synth_mint_count

    @synth_mint_count.setter
    def synth_mint_count(self, synth_mint_count):
        """Sets the synth_mint_count of this StatsData.

        Int64, number of swaps from Rune to Synth since beginning.  # noqa: E501

        :param synth_mint_count: The synth_mint_count of this StatsData.  # noqa: E501
        :type: str
        """
        if synth_mint_count is None:
            raise ValueError("Invalid value for `synth_mint_count`, must not be `None`")  # noqa: E501

        self._synth_mint_count = synth_mint_count

    @property
    def to_asset_count(self):
        """Gets the to_asset_count of this StatsData.  # noqa: E501

        Int64, number of swaps from Rune to Asset since beginning.  # noqa: E501

        :return: The to_asset_count of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._to_asset_count

    @to_asset_count.setter
    def to_asset_count(self, to_asset_count):
        """Sets the to_asset_count of this StatsData.

        Int64, number of swaps from Rune to Asset since beginning.  # noqa: E501

        :param to_asset_count: The to_asset_count of this StatsData.  # noqa: E501
        :type: str
        """
        if to_asset_count is None:
            raise ValueError("Invalid value for `to_asset_count`, must not be `None`")  # noqa: E501

        self._to_asset_count = to_asset_count

    @property
    def to_rune_count(self):
        """Gets the to_rune_count of this StatsData.  # noqa: E501

        Int64, number of swaps from Asset to Rune since beginning.  # noqa: E501

        :return: The to_rune_count of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._to_rune_count

    @to_rune_count.setter
    def to_rune_count(self, to_rune_count):
        """Sets the to_rune_count of this StatsData.

        Int64, number of swaps from Asset to Rune since beginning.  # noqa: E501

        :param to_rune_count: The to_rune_count of this StatsData.  # noqa: E501
        :type: str
        """
        if to_rune_count is None:
            raise ValueError("Invalid value for `to_rune_count`, must not be `None`")  # noqa: E501

        self._to_rune_count = to_rune_count

    @property
    def unique_swapper_count(self):
        """Gets the unique_swapper_count of this StatsData.  # noqa: E501

        Deprecated, it's always 0.  # noqa: E501

        :return: The unique_swapper_count of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._unique_swapper_count

    @unique_swapper_count.setter
    def unique_swapper_count(self, unique_swapper_count):
        """Sets the unique_swapper_count of this StatsData.

        Deprecated, it's always 0.  # noqa: E501

        :param unique_swapper_count: The unique_swapper_count of this StatsData.  # noqa: E501
        :type: str
        """
        if unique_swapper_count is None:
            raise ValueError("Invalid value for `unique_swapper_count`, must not be `None`")  # noqa: E501

        self._unique_swapper_count = unique_swapper_count

    @property
    def withdraw_count(self):
        """Gets the withdraw_count of this StatsData.  # noqa: E501

        Int64, number of withdraws since beginning.  # noqa: E501

        :return: The withdraw_count of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._withdraw_count

    @withdraw_count.setter
    def withdraw_count(self, withdraw_count):
        """Sets the withdraw_count of this StatsData.

        Int64, number of withdraws since beginning.  # noqa: E501

        :param withdraw_count: The withdraw_count of this StatsData.  # noqa: E501
        :type: str
        """
        if withdraw_count is None:
            raise ValueError("Invalid value for `withdraw_count`, must not be `None`")  # noqa: E501

        self._withdraw_count = withdraw_count

    @property
    def withdraw_volume(self):
        """Gets the withdraw_volume of this StatsData.  # noqa: E501

        Int64(e8), total of withdraws since beginning.   # noqa: E501

        :return: The withdraw_volume of this StatsData.  # noqa: E501
        :rtype: str
        """
        return self._withdraw_volume

    @withdraw_volume.setter
    def withdraw_volume(self, withdraw_volume):
        """Sets the withdraw_volume of this StatsData.

        Int64(e8), total of withdraws since beginning.   # noqa: E501

        :param withdraw_volume: The withdraw_volume of this StatsData.  # noqa: E501
        :type: str
        """
        if withdraw_volume is None:
            raise ValueError("Invalid value for `withdraw_volume`, must not be `None`")  # noqa: E501

        self._withdraw_volume = withdraw_volume

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StatsData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatsData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InlineResponse200(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'actions': 'list[Action]',
        'count': 'str',
        'meta': 'ActionMeta'
    }

    attribute_map = {
        'actions': 'actions',
        'count': 'count',
        'meta': 'meta'
    }

    def __init__(self, actions=None, count=None, meta=None):  # noqa: E501
        """InlineResponse200 - a model defined in Swagger"""  # noqa: E501
        self._actions = None
        self._count = None
        self._meta = None
        self.discriminator = None
        self.actions = actions
        if count is not None:
            self.count = count
        self.meta = meta

    @property
    def actions(self):
        """Gets the actions of this InlineResponse200.  # noqa: E501


        :return: The actions of this InlineResponse200.  # noqa: E501
        :rtype: list[Action]
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """Sets the actions of this InlineResponse200.


        :param actions: The actions of this InlineResponse200.  # noqa: E501
        :type: list[Action]
        """
        if actions is None:
            raise ValueError("Invalid value for `actions`, must not be `None`")  # noqa: E501

        self._actions = actions

    @property
    def count(self):
        """Gets the count of this InlineResponse200.  # noqa: E501

        Int64, number of results matching the given filters. It may be -1 if Midgard is having trouble counting the results and has to cancel the count query (temporary fix). Also, if new action parameters is used it won't be returned.   # noqa: E501

        :return: The count of this InlineResponse200.  # noqa: E501
        :rtype: str
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this InlineResponse200.

        Int64, number of results matching the given filters. It may be -1 if Midgard is having trouble counting the results and has to cancel the count query (temporary fix). Also, if new action parameters is used it won't be returned.   # noqa: E501

        :param count: The count of this InlineResponse200.  # noqa: E501
        :type: str
        """

        self._count = count

    @property
    def meta(self):
        """Gets the meta of this InlineResponse200.  # noqa: E501


        :return: The meta of this InlineResponse200.  # noqa: E501
        :rtype: ActionMeta
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """Sets the meta of this InlineResponse200.


        :param meta: The meta of this InlineResponse200.  # noqa: E501
        :type: ActionMeta
        """
        if meta is None:
            raise ValueError("Invalid value for `meta`, must not be `None`")  # noqa: E501

        self._meta = meta

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StreamingSwapMeta(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'count': 'str',
        'deposited_coin': 'Coin',
        'failed_swap_reasons': 'list[str]',
        'failed_swaps': 'list[str]',
        'in_coin': 'Coin',
        'interval': 'str',
        'last_height': 'str',
        'out_coin': 'Coin',
        'quantity': 'str'
    }

    attribute_map = {
        'count': 'count',
        'deposited_coin': 'depositedCoin',
        'failed_swap_reasons': 'failedSwapReasons',
        'failed_swaps': 'failedSwaps',
        'in_coin': 'inCoin',
        'interval': 'interval',
        'last_height': 'lastHeight',
        'out_coin': 'outCoin',
        'quantity': 'quantity'
    }

    def __init__(self, count=None, deposited_coin=None, failed_swap_reasons=None, failed_swaps=None, in_coin=None, interval=None, last_height=None, out_coin=None, quantity=None):  # noqa: E501
        """StreamingSwapMeta - a model defined in Swagger"""  # noqa: E501
        self._count = None
        self._deposited_coin = None
        self._failed_swap_reasons = None
        self._failed_swaps = None
        self._in_coin = None
        self._interval = None
        self._last_height = None
        self._out_coin = None
        self._quantity = None
        self.discriminator = None
        self.count = count
        self.deposited_coin = deposited_coin
        if failed_swap_reasons is not None:
            self.failed_swap_reasons = failed_swap_reasons
        if failed_swaps is not None:
            self.failed_swaps = failed_swaps
        self.in_coin = in_coin
        self.interval = interval
        self.last_height = last_height
        self.out_coin = out_coin
        self.quantity = quantity

    @property
    def count(self):
        """Gets the count of this StreamingSwapMeta.  # noqa: E501

        Int64, Number of swaps events which already happened.  # noqa: E501

        :return: The count of this StreamingSwapMeta.  # noqa: E501
        :rtype: str
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this StreamingSwapMeta.

        Int64, Number of swaps events which already happened.  # noqa: E501

        :param count: The count of this StreamingSwapMeta.  # noqa: E501
        :type: str
        """
        if count is None:
            raise ValueError("Invalid value for `count`, must not be `None`")  # noqa: E501

        self._count = count

    @property
    def deposited_coin(self):
        """Gets the deposited_coin of this StreamingSwapMeta.  # noqa: E501


        :return: The deposited_coin of this StreamingSwapMeta.  # noqa: E501
        :rtype: Coin
        """
        return self._deposited_coin

    @deposited_coin.setter
    def deposited_coin(self, deposited_coin):
        """Sets the deposited_coin of this StreamingSwapMeta.


        :param deposited_coin: The deposited_coin of this StreamingSwapMeta.  # noqa: E501
        :type: Coin
        """
        if deposited_coin is None:
            raise ValueError("Invalid value for `deposited_coin`, must not be `None`")  # noqa: E501

        self._deposited_coin = deposited_coin

    @property
    def failed_swap_reasons(self):
        """Gets the failed_swap_reasons of this StreamingSwapMeta.  # noqa: E501

        Array of failed swaps reasons in streaming swap.  # noqa: E501

        :return: The failed_swap_reasons of this StreamingSwapMeta.  # noqa: E501
        :rtype: list[str]
        """
        return self._failed_swap_reasons

    @failed_swap_reasons.setter
    def failed_swap_reasons(self, failed_swap_reasons):
        """Sets the failed_swap_reasons of this StreamingSwapMeta.

        Array of failed swaps reasons in streaming swap.  # noqa: E501

        :param failed_swap_reasons: The failed_swap_reasons of this StreamingSwapMeta.  # noqa: E501
        :type: list[str]
        """

        self._failed_swap_reasons = failed_swap_reasons

    @property
    def failed_swaps(self):
        """Gets the failed_swaps of this StreamingSwapMeta.  # noqa: E501

        Array of failed swaps index in streaming swap.  # noqa: E501

        :return: The failed_swaps of this StreamingSwapMeta.  # noqa: E501
        :rtype: list[str]
        """
        return self._failed_swaps

    @failed_swaps.setter
    def failed_swaps(self, failed_swaps):
        """Sets the failed_swaps of this StreamingSwapMeta.

        Array of failed swaps index in streaming swap.  # noqa: E501

        :param failed_swaps: The failed_swaps of this StreamingSwapMeta.  # noqa: E501
        :type: list[str]
        """

        self._failed_swaps = failed_swaps

    @property
    def in_coin(self):
        """Gets the in_coin of this StreamingSwapMeta.  # noqa: E501


        :return: The in_coin of this StreamingSwapMeta.  # noqa: E501
        :rtype: Coin
        """
        return self._in_coin

    @in_coin.setter
    def in_coin(self, in_coin):
        """Sets the in_coin of this StreamingSwapMeta.


        :param in_coin: The in_coin of this StreamingSwapMeta.  # noqa: E501
        :type: Coin
        """
        if in_coin is None:
            raise ValueError("Invalid value for `in_coin`, must not be `None`")  # noqa: E501

        self._in_coin = in_coin

    @property
    def interval(self):
        """Gets the interval of this StreamingSwapMeta.  # noqa: E501

        Int64, Number of blocks between swpas. (Blocks/Swap) E.g. 1 means every block.  # noqa: E501

        :return: The interval of this StreamingSwapMeta.  # noqa: E501
        :rtype: str
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this StreamingSwapMeta.

        Int64, Number of blocks between swpas. (Blocks/Swap) E.g. 1 means every block.  # noqa: E501

        :param interval: The interval of this StreamingSwapMeta.  # noqa: E501
        :type: str
        """
        if interval is None:
            raise ValueError("Invalid value for `interval`, must not be `None`")  # noqa: E501

        self._interval = interval

    @property
    def last_height(self):
        """Gets the last_height of this StreamingSwapMeta.  # noqa: E501

        Int64, The last blockheight the final swap happend (not outbound). This field will be missing until the final swap happens.   # noqa: E501

        :return: The last_height of this StreamingSwapMeta.  # noqa: E501
        :rtype: str
        """
        return self._last_height

    @last_height.setter
    def last_height(self, last_height):
        """Sets the last_height of this StreamingSwapMeta.

        Int64, The last blockheight the final swap happend (not outbound). This field will be missing until the final swap happens.   # noqa: E501

        :param last_height: The last_height of this StreamingSwapMeta.  # noqa: E501
        :type: str
        """
        if last_height is None:
            raise ValueError("Invalid value for `last_height`, must not be `None`")  # noqa: E501

        self._last_height = last_height

    @property
    def out_coin(self):
        """Gets the out_coin of this StreamingSwapMeta.  # noqa: E501


        :return: The out_coin of this StreamingSwapMeta.  # noqa: E501
        :rtype: Coin
        """
        return self._out_coin

    @out_coin.setter
    def out_coin(self, out_coin):
        """Sets the out_coin of this StreamingSwapMeta.


        :param out_coin: The out_coin of this StreamingSwapMeta.  # noqa: E501
        :type: Coin
        """
        if out_coin is None:
            raise ValueError("Invalid value for `out_coin`, must not be `None`")  # noqa: E501

        self._out_coin = out_coin

    @property
    def quantity(self):
        """Gets the quantity of this StreamingSwapMeta.  # noqa: E501

        Int64,  Number of swaps which thorchain is planning to execute. Total count at the end might be less.   # noqa: E501

        :return: The quantity of this StreamingSwapMeta.  # noqa: E501
        :rtype: str
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this StreamingSwapMeta.

        Int64,  Number of swaps which thorchain is planning to execute. Total count at the end might be less.   # noqa: E501

        :param quantity: The quantity of this StreamingSwapMeta.  # noqa: E501
        :type: str
        """
        if quantity is None:
            raise ValueError("Invalid value for `quantity`, must not be `None`")  # noqa: E501

        self._quantity = quantity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StreamingSwapMeta, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamingSwapMeta):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
